@@ -910,6 +910,12 @@ class BinCopyTest(unittest.TestCase):
         self.assertEqual(str(cm.exception),
                          'size 4 is not a multiple of alignment 8')
 
+        with self.assertRaises(bincopy.Error) as cm:
+            list(binfile.segments.chunks(padding=b'\xff\xff'))
+
+        self.assertEqual(str(cm.exception),
+                         r"padding must be a word value (size 1), got b'\xff\xff'")
+
     def test_segment(self):
         binfile = bincopy.BinFile()
         binfile.add_binary(b'\x00\x01\x02\x03\x04', 2)
@@ -1841,6 +1847,83 @@ Data ranges:
         with open('tests/files/empty_main.bin', 'rb') as fin:
             self.assertEqual(binfile.as_binary(padding=b'\x00'), fin.read())
 
+    def test_segment_len(self):
+        length = 0x100
+        word_size_bytes = 1
+        segment = bincopy.Segment(0, length, bytes(length), word_size_bytes)
+        self.assertEqual(length, len(segment))
+
+    def test_segment_len_16(self):
+        length = 0x100
+        word_size_bytes = 2
+        segment = bincopy.Segment(0,
+                                  length,
+                                  bytes(length * word_size_bytes),
+                                  word_size_bytes)
+        self.assertEqual(length, len(segment))
+
+    def test_add_microchip_hex_record(self):
+        binfile = bincopy.BinFile()
+        binfile.add_microchip_hex(':02000E00E4C943')
+        self.assertEqual(0x0007, binfile.minimum_address)
+        first_word = int.from_bytes(binfile[:binfile.minimum_address + 1], 'little')
+        self.assertEqual(0xC9E4, first_word)
+
+    def test_microchip_hex(self):
+        binfile = bincopy.BinFile()
+
+        with open("tests/files/in.hex", "r") as fin:
+            binfile.add_microchip_hex(fin.read())
+
+        with open("tests/files/in.hex", "r") as fin:
+            self.assertEqual(binfile.as_microchip_hex(), fin.read())
+
+        # Add and overwrite the data.
+        binfile = bincopy.BinFile()
+        binfile.add_microchip_hex_file("tests/files/in.hex")
+        binfile.add_microchip_hex_file("tests/files/in.hex", overwrite=True)
+
+        with open("tests/files/in.hex") as fin:
+            self.assertEqual(binfile.as_microchip_hex(), fin.read())
+
+    def test_chunk_padding(self):
+        records = (':02000004000AF0\n'
+                   ':10B8440000000000000000009630000007770000B0\n')
+        hexfile = bincopy.BinFile()
+        hexfile.add_ihex(records)
+        align = 8
+        size = 16
+        chunks = hexfile.segments.chunks(size=size, alignment=align, padding=b'\xff')
+        chunks = list(chunks)
+        assert not any(c.address % align for c in chunks)
+        assert not any(len(c) % align for c in chunks)
+
+    def test_merge_chunks(self):
+        records = (':0A0000001010101010101010101056\n'
+                   ':0A000E001010101010101010101048\n')
+        hexfile = bincopy.BinFile()
+        hexfile.add_ihex(records)
+        align = 8
+        size = 16
+        chunks = hexfile.segments.chunks(size=size, alignment=align, padding=b'\xff')
+        chunks = list(chunks)
+        assert list(chunks[-1]) == [8, b'\x10\x10\xff\xff\xff\xff\x10\x10\x10\x10\x10'
+                                       b'\x10\x10\x10\x10\x10']
+
+    def test_merge_chunks_16(self):
+        records = (':1000000010101010101010101010101010101010F0\n'
+                   ':10000A0010101010101010101010101010101010E6\n')
+        hexfile = bincopy.BinFile(word_size_bits=16)
+        hexfile.add_ihex(records)
+        align = 6
+        size = 12
+        chunks = hexfile.segments.chunks(size=size, alignment=align,
+                                         padding=b'\xff\xff')
+        chunks = list(chunks)
+        assert list(chunks[-1]) == [6, b'\x10\x10\x10\x10\xff\xff\xff\xff\x10\x10\x10'
+                                       b'\x10\x10\x10\x10\x10\x10\x10\x10\x10\x10\x10'
+                                       b'\x10\x10']
+
 
 if __name__ == '__main__':
     unittest.main()
